use anyhow::Context;
use clap::arg;
use prymn_agent::{self_update, server};
use tracing::Level;
use tracing_subscriber::{filter::Targets, layer::SubscriberExt, util::SubscriberInitExt};

fn main() -> anyhow::Result<()> {
    // Debug subscriber, should be configurable in the future
    tracing_subscriber::fmt()
        .with_max_level(Level::TRACE)
        .pretty()
        .without_time()
        .with_file(false)
        .finish()
        .with(
            Targets::new()
                .with_target("prymn_agent", Level::DEBUG)
                .with_target("tower_http", Level::DEBUG),
        )
        .init();

    let command = clap::Command::new(env!("CARGO_BIN_NAME"))
        .version(env!("CARGO_PKG_VERSION"))
        .arg(arg!(--install <TOKEN> "Install this agent binary to the system").exclusive(true))
        .try_get_matches()
        .unwrap_or_else(|e| e.exit());

    if let Some(token) = command.get_one::<String>("install") {
        self_update::install(token).context("failed to install the agent to the system")
    } else {
        server::run()
    }
}
